@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.23.2.5 2000/11/22 16:04:59 bazsi Exp $
+ * $Id: sources.c,v 1.25.2.1 2000/11/29 11:04:29 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -100,8 +100,8 @@ do_read_line(struct read_handler **h,
 	eol = memchr(closure->buffer, '\0', closure->pos);
 	if (eol == NULL)
 		eol = memchr(closure->buffer, '\n', closure->pos);
-	if (!eol && closure->pos == MAX_LINE) {
-		/* our buffer is full, we have to flush it */
+	if (!eol && closure->pos) {
+		/* we don't have a terminating nl nor \0 */
 		do_handle_line(closure, closure->pos, closure->buffer, salen ? (abstract_addr *) &sabuf : NULL, salen);
 		closure->pos = 0;
 		return ST_OK | ST_GOON;
